from socaity.sdk.replicate.camenduru.metavoice import metavoice
from socaity.sdk.replicate.meta.llama_4_maverick_instruct import llama_4_maverick_instruct
from socaity.sdk.replicate.meta.meta_llama_3_1_405b_instruct import meta_llama_3_1_405b_instruct
from socaity.sdk.replicate.meta.meta_llama_3_70b_instruct import meta_llama_3_70b_instruct
from socaity.sdk.replicate.meta.meta_llama_3_8b import meta_llama_3_8b
from socaity.sdk.replicate.meta.meta_llama_3_8b_instruct import meta_llama_3_8b_instruct
from socaity.sdk.replicate.meta.musicgen import musicgen
from socaity.sdk.replicate.meta.sam_2 import sam_2
from socaity.sdk.replicate.meta.sam_2_video import sam_2_video