from socaity.sdk.replicate.cuuupid.cogvideox_5b import cogvideox_5b
from socaity.sdk.replicate.cuuupid.flux_lineart import flux_lineart
from socaity.sdk.replicate.cuuupid.gte_qwen2_7b_instruct import gte_qwen2_7b_instruct