from socaity.sdk.replicate.google_deepmind.gemma_2b import gemma_2b
from socaity.sdk.replicate.google_deepmind.gemma_2b_it import gemma_2b_it
from socaity.sdk.replicate.google_deepmind.gemma_7b import gemma_7b
from socaity.sdk.replicate.google_deepmind.gemma_7b_it import gemma_7b_it