from socaity.sdk.replicate.justmalhar.flux_mobile_ui import flux_mobile_ui
from socaity.sdk.replicate.justmalhar.flux_sketchnotes import flux_sketchnotes
from socaity.sdk.replicate.justmalhar.flux_thumbnails import flux_thumbnails