from socaity.sdk.replicate.roelfrenkema.fatherofdragons import fatherofdragons
from socaity.sdk.replicate.roelfrenkema.flux1_lora_aurora import flux1_lora_aurora
from socaity.sdk.replicate.roelfrenkema.flux1_lora_betty import flux1_lora_betty
from socaity.sdk.replicate.roelfrenkema.flux1_lora_watercolors import flux1_lora_watercolors