from socaity.sdk.replicate._01_ai.yi_34b_chat import yi_34b_chat
from socaity.sdk.replicate._01_ai.yi_6b import yi_6b
from socaity.sdk.replicate._01_ai.yi_6b_chat import yi_6b_chat
from socaity.sdk.replicate._0xdeadd.flux_your_model_name import flux_your_model_name
from socaity.sdk.replicate._0xtuba.archillect_lora import archillect_lora
from socaity.sdk.replicate._10xcrazyhorse.bonkfa import bonkfa
from socaity.sdk.replicate._851_labs.background_remover import background_remover
from socaity.sdk.replicate.abyssalsoul.cyberdad import cyberdad
from socaity.sdk.replicate.adidoes.whisperx_video_transcribe import whisperx_video_transcribe
from socaity.sdk.replicate.adirik.e5_mistral_7b_instruct import e5_mistral_7b_instruct
from socaity.sdk.replicate.adirik.flux_cinestill import flux_cinestill
from socaity.sdk.replicate.adirik.flux_fantasy_architecture import flux_fantasy_architecture
from socaity.sdk.replicate.adirik.grounding_dino import grounding_dino
from socaity.sdk.replicate.adirik.imagedream import imagedream
from socaity.sdk.replicate.adirik.interior_design import interior_design
from socaity.sdk.replicate.adirik.mamba_130m import mamba_130m
from socaity.sdk.replicate.adirik.mamba_1_4b import mamba_1_4b
from socaity.sdk.replicate.adirik.mamba_2_8b import mamba_2_8b
from socaity.sdk.replicate.adirik.mamba_2_8b_slimpj import mamba_2_8b_slimpj
from socaity.sdk.replicate.adirik.mamba_370m import mamba_370m
from socaity.sdk.replicate.adirik.mamba_790m import mamba_790m
from socaity.sdk.replicate.adirik.mvdream import mvdream
from socaity.sdk.replicate.adirik.owlvit_base_patch32 import owlvit_base_patch32
from socaity.sdk.replicate.adirik.realvisxl_v3_0_turbo import realvisxl_v3_0_turbo
from socaity.sdk.replicate.adirik.realvisxl_v4_0 import realvisxl_v4_0
from socaity.sdk.replicate.adirik.styletts2 import styletts2
from socaity.sdk.replicate.adirik.text2tex import text2tex
from socaity.sdk.replicate.adirik.texture import texture
from socaity.sdk.replicate.adirik.wonder3d import wonder3d
from socaity.sdk.replicate.advoworks.lokidog import lokidog
from socaity.sdk.replicate.afiaka87.tortoise_tts import tortoise_tts
from socaity.sdk.replicate.afterpeak.flux_slowed import flux_slowed
from socaity.sdk.replicate.agusdor.pen_lettering_flux_lora import pen_lettering_flux_lora
from socaity.sdk.replicate.ah77ac.majestyrabbit_flux_lora import majestyrabbit_flux_lora
from socaity.sdk.replicate.ahmdyassr.mask_clothing import mask_clothing
from socaity.sdk.replicate.ai_forever.kandinsky_2 import kandinsky_2
from socaity.sdk.replicate.ai_forever.kandinsky_2_1 import kandinsky_2_1
from socaity.sdk.replicate.ai_forever.kandinsky_2_2 import kandinsky_2_2
from socaity.sdk.replicate.aj1357.ai_tshirt_mockup import ai_tshirt_mockup
from socaity.sdk.replicate.aleksa_codes.flux_ghibsky_illustration import flux_ghibsky_illustration
from socaity.sdk.replicate.alekseycalvin.acsoonr_flux import acsoonr_flux
from socaity.sdk.replicate.alexvoorheesmusic.yanisse import yanisse
from socaity.sdk.replicate.ali_vilab.i2vgen_xl import i2vgen_xl
from socaity.sdk.replicate.allenhung1025.looptest import looptest
from socaity.sdk.replicate.allthingsai69.sydneysweeney import sydneysweeney
from socaity.sdk.replicate.andreasjansson.blip_2 import blip_2
from socaity.sdk.replicate.andreasjansson.cantable_diffuguesion import cantable_diffuguesion
from socaity.sdk.replicate.andreasjansson.clip_features import clip_features
from socaity.sdk.replicate.andreasjansson.flux_goo import flux_goo
from socaity.sdk.replicate.andreasjansson.flux_me import flux_me
from socaity.sdk.replicate.andreasjansson.flux_shapes import flux_shapes
from socaity.sdk.replicate.andreasjansson.illusion import illusion
from socaity.sdk.replicate.andreasjansson.llama_2_13b_embeddings import llama_2_13b_embeddings
from socaity.sdk.replicate.andreasjansson.music_inpainting_bert import music_inpainting_bert
from socaity.sdk.replicate.andreasjansson.musicgen_looper import musicgen_looper
from socaity.sdk.replicate.andreasjansson.stable_diffusion_animation import stable_diffusion_animation
from socaity.sdk.replicate.andreasjansson.tile_morph import tile_morph
from socaity.sdk.replicate.andreasjansson.wan_1_3b_inpaint import wan_1_3b_inpaint
from socaity.sdk.replicate.annahung31.emopia import emopia
from socaity.sdk.replicate.anotherjesse.zeroscope_v2_xl import zeroscope_v2_xl
from socaity.sdk.replicate.aperture_2.hido import hido
from socaity.sdk.replicate.apolinario.flux_tarot_v1 import flux_tarot_v1
from socaity.sdk.replicate.aramintak.enna_sketch_style import enna_sketch_style
from socaity.sdk.replicate.aramintak.flux_film_foto import flux_film_foto
from socaity.sdk.replicate.aramintak.flux_frosting_lane import flux_frosting_lane
from socaity.sdk.replicate.aramintak.flux_koda import flux_koda
from socaity.sdk.replicate.aramintak.flux_softserve_anime import flux_softserve_anime
from socaity.sdk.replicate.aramintak.linnea_flux_beta import linnea_flux_beta
from socaity.sdk.replicate.aramintak.mooniverse import mooniverse
from socaity.sdk.replicate.arcanite24.animation2k_flux import animation2k_flux
from socaity.sdk.replicate.arielreplicate.deoldify_video import deoldify_video
from socaity.sdk.replicate.arielreplicate.robust_video_matting import robust_video_matting
from socaity.sdk.replicate.arielreplicate.stable_diffusion_infinite_zoom import stable_diffusion_infinite_zoom
from socaity.sdk.replicate.astronautdavid1.mad2_flux_lora import mad2_flux_lora
from socaity.sdk.replicate.awerks.neon_tts import neon_tts
from socaity.sdk.replicate.banta2000.mytestmodel import mytestmodel
from socaity.sdk.replicate.beautyyuyanli.multilingual_e5_large import multilingual_e5_large
from socaity.sdk.replicate.benj_edwards.dads_uppercase_2500_steps import dads_uppercase_2500_steps
from socaity.sdk.replicate.bingbangboom_lab.flux_dreamscape import flux_dreamscape
from socaity.sdk.replicate.black_forest_labs.flux_schnell import flux_schnell
from socaity.sdk.replicate.bonapartee.thumbnail_generator import thumbnail_generator
from socaity.sdk.replicate.brunnolou.flux_texture_abstract_painting import flux_texture_abstract_painting
from socaity.sdk.replicate.buildingwithai.ai_jo import ai_jo
from socaity.sdk.replicate.bytedance.hyper_flux_16step import hyper_flux_16step
from socaity.sdk.replicate.bytedance.hyper_flux_8step import hyper_flux_8step
from socaity.sdk.replicate.bytedance.sdxl_lightning_4step import sdxl_lightning_4step
from socaity.sdk.replicate.camenduru.lgm import lgm
from socaity.sdk.replicate.camenduru.lgm_ply_to_glb import lgm_ply_to_glb
from socaity.sdk.replicate.camenduru.metavoice import metavoice
from socaity.sdk.replicate.camenduru.tripo_sr import tripo_sr
from socaity.sdk.replicate.carlosperz88.teslacyberbeast import teslacyberbeast
from socaity.sdk.replicate.cddietz.michael import michael
from socaity.sdk.replicate.cdreier.golang_gopher_flux import golang_gopher_flux
from socaity.sdk.replicate.center_for_curriculum_redesign.bge_1_5_query_embeddings import bge_1_5_query_embeddings
from socaity.sdk.replicate.charlesmccarthy.addwatermark import addwatermark
from socaity.sdk.replicate.chatworks.luchtpods import luchtpods
from socaity.sdk.replicate.chenxwh.cogvlm2_video import cogvlm2_video
from socaity.sdk.replicate.chigozienri.image_urls_to_video import image_urls_to_video
from socaity.sdk.replicate.chigozienri.mediapipe_face import mediapipe_face
from socaity.sdk.replicate.cjwbw.controlvideo import controlvideo
from socaity.sdk.replicate.cjwbw.damo_text_to_video import damo_text_to_video
from socaity.sdk.replicate.cjwbw.parler_tts import parler_tts
from socaity.sdk.replicate.cjwbw.rembg import rembg
from socaity.sdk.replicate.cjwbw.rudalle_sr import rudalle_sr
from socaity.sdk.replicate.cjwbw.seamless_communication import seamless_communication
from socaity.sdk.replicate.cjwbw.semantic_segment_anything import semantic_segment_anything
from socaity.sdk.replicate.cjwbw.shap_e import shap_e
from socaity.sdk.replicate.cjwbw.supir import supir
from socaity.sdk.replicate.cjwbw.text2video_zero import text2video_zero
from socaity.sdk.replicate.cjwbw.videocrafter import videocrafter
from socaity.sdk.replicate.cjwbw.voicecraft import voicecraft
from socaity.sdk.replicate.ckizer.ckizer_64 import ckizer_64
from socaity.sdk.replicate.codingfu.bayc import bayc
from socaity.sdk.replicate.cristobalascencio.florentino import florentino
from socaity.sdk.replicate.cristobalascencio.wirra import wirra
from socaity.sdk.replicate.cswry.seesr import seesr
from socaity.sdk.replicate.ctrimm.backyard_sports_character_creator import backyard_sports_character_creator
from socaity.sdk.replicate.cuuupid.cogvideox_5b import cogvideox_5b
from socaity.sdk.replicate.cuuupid.flux_lineart import flux_lineart
from socaity.sdk.replicate.cuuupid.gte_qwen2_7b_instruct import gte_qwen2_7b_instruct
from socaity.sdk.replicate.daanelson.imagebind import imagebind
from socaity.sdk.replicate.daanelson.whisperx import whisperx
from socaity.sdk.replicate.daanelson.yolox import yolox
from socaity.sdk.replicate.darionaviar.cinthia import cinthia
from socaity.sdk.replicate.darionaviar.dario_naviar import dario_naviar
from socaity.sdk.replicate.datacte.flux_aesthetic_anime import flux_aesthetic_anime
from socaity.sdk.replicate.datacte.flux_synthetic_anime import flux_synthetic_anime
from socaity.sdk.replicate.datacte.proteus_v0_2 import proteus_v0_2
from socaity.sdk.replicate.datacte.proteus_v0_3 import proteus_v0_3
from socaity.sdk.replicate.davidkwcheng.jessicayu02 import jessicayu02
from socaity.sdk.replicate.davisbrown.flux_half_illustration import flux_half_illustration
from socaity.sdk.replicate.davisbrown.photo_glow import photo_glow
from socaity.sdk.replicate.dcamsdev.klm_lora_flux import klm_lora_flux
from socaity.sdk.replicate.declare_lab.mustango import mustango
from socaity.sdk.replicate.deepfates.deepfits_flux_dev import deepfits_flux_dev
from socaity.sdk.replicate.deepfates.flux_hot_zuck import flux_hot_zuck
from socaity.sdk.replicate.deepseek_ai.deepseek_r1 import deepseek_r1
from socaity.sdk.replicate.deepseek_ai.deepseek_v3 import deepseek_v3
from socaity.sdk.replicate.deforum.deforum_stable_diffusion import deforum_stable_diffusion
from socaity.sdk.replicate.derrrick.flux_70s_bands import flux_70s_bands
from socaity.sdk.replicate.dfrostar.hermes_kellybag import hermes_kellybag
from socaity.sdk.replicate.digitaljohn.urban_narrative import urban_narrative
from socaity.sdk.replicate.dunaevai135.tst2_d import tst2_d
from socaity.sdk.replicate.dunaevai135.tst_svt3 import tst_svt3
from socaity.sdk.replicate.dunaevai135.tst_trn import tst_trn
from socaity.sdk.replicate.emunozhern.fluxtok import fluxtok
from socaity.sdk.replicate.enkey08.ganpatibappa import ganpatibappa
from socaity.sdk.replicate.esgfit.flux_andreas import flux_andreas
from socaity.sdk.replicate.evtn.pouyippie import pouyippie
from socaity.sdk.replicate.falcons_ai.nsfw_image_detection import nsfw_image_detection
from socaity.sdk.replicate.fanyiy.flux_notion_illustration import flux_notion_illustration
from socaity.sdk.replicate.felixyifeiwang.eom_phase1 import eom_phase1
from socaity.sdk.replicate.fermatresearch.dpo_sdxl_controlnet_lora import dpo_sdxl_controlnet_lora
from socaity.sdk.replicate.fermatresearch.high_resolution_controlnet_tile import high_resolution_controlnet_tile
from socaity.sdk.replicate.fermatresearch.magic_image_refiner import magic_image_refiner
from socaity.sdk.replicate.fermatresearch.sdxl_controlnet_lora import sdxl_controlnet_lora
from socaity.sdk.replicate.fermatresearch.spanish_f5_tts import spanish_f5_tts
from socaity.sdk.replicate.ferunelli.chadmeme import chadmeme
from socaity.sdk.replicate.fesilva196.lipex import lipex
from socaity.sdk.replicate.fewjative.ultimate_sd_upscale import ultimate_sd_upscale
from socaity.sdk.replicate.fictions_ai.autocaption import autocaption
from socaity.sdk.replicate.firtoz.trellis import trellis
from socaity.sdk.replicate.fofr._0_1_webp import _0_1_webp
from socaity.sdk.replicate.fofr.any_comfyui_workflow import any_comfyui_workflow
from socaity.sdk.replicate.fofr.audio_to_waveform import audio_to_waveform
from socaity.sdk.replicate.fofr.aura_flow import aura_flow
from socaity.sdk.replicate.fofr.controlnet_preprocessors import controlnet_preprocessors
from socaity.sdk.replicate.fofr.flux_2004 import flux_2004
from socaity.sdk.replicate.fofr.flux_80s_cyberpunk import flux_80s_cyberpunk
from socaity.sdk.replicate.fofr.flux_bad_70s_food import flux_bad_70s_food
from socaity.sdk.replicate.fofr.flux_beyond_horizon import flux_beyond_horizon
from socaity.sdk.replicate.fofr.flux_black_light import flux_black_light
from socaity.sdk.replicate.fofr.flux_brighton_west_pier import flux_brighton_west_pier
from socaity.sdk.replicate.fofr.flux_cassette_futurism import flux_cassette_futurism
from socaity.sdk.replicate.fofr.flux_color import flux_color
from socaity.sdk.replicate.fofr.flux_cross_section import flux_cross_section
from socaity.sdk.replicate.fofr.flux_cyberpunk_typeface import flux_cyberpunk_typeface
from socaity.sdk.replicate.fofr.flux_hyundai_n_vision_74 import flux_hyundai_n_vision_74
from socaity.sdk.replicate.fofr.flux_jwst import flux_jwst
from socaity.sdk.replicate.fofr.flux_macro_texture import flux_macro_texture
from socaity.sdk.replicate.fofr.flux_minecraft_movie import flux_minecraft_movie
from socaity.sdk.replicate.fofr.flux_mjv3 import flux_mjv3
from socaity.sdk.replicate.fofr.flux_mona_lisa import flux_mona_lisa
from socaity.sdk.replicate.fofr.flux_myst import flux_myst
from socaity.sdk.replicate.fofr.flux_neo_1x import flux_neo_1x
from socaity.sdk.replicate.fofr.flux_pixar_cars import flux_pixar_cars
from socaity.sdk.replicate.fofr.flux_spitting_image import flux_spitting_image
from socaity.sdk.replicate.fofr.flux_tessellate import flux_tessellate
from socaity.sdk.replicate.fofr.flux_wrong import flux_wrong
from socaity.sdk.replicate.fofr.flux_y2k import flux_y2k
from socaity.sdk.replicate.fofr.frames_to_video import frames_to_video
from socaity.sdk.replicate.fofr.latent_consistency_model import latent_consistency_model
from socaity.sdk.replicate.fofr.musicgen_choral import musicgen_choral
from socaity.sdk.replicate.fofr.realvisxl_v3_multi_controlnet_lora import realvisxl_v3_multi_controlnet_lora
from socaity.sdk.replicate.fofr.sdxl_emoji import sdxl_emoji
from socaity.sdk.replicate.fofr.sdxl_multi_controlnet_lora import sdxl_multi_controlnet_lora
from socaity.sdk.replicate.fofr.sticker_maker import sticker_maker
from socaity.sdk.replicate.fofr.toolkit import toolkit
from socaity.sdk.replicate.fofr.tooncrafter import tooncrafter
from socaity.sdk.replicate.fofr.video_morpher import video_morpher
from socaity.sdk.replicate.fofr.video_to_frames import video_to_frames
from socaity.sdk.replicate.fofr.wan2_1_with_lora import wan2_1_with_lora
from socaity.sdk.replicate.gajendrajha09.fluxloramimi import fluxloramimi
from socaity.sdk.replicate.galverse.mama_flux_v1 import mama_flux_v1
from socaity.sdk.replicate.genericdeag.comic_style import comic_style
from socaity.sdk.replicate.genmoai.mochi_1 import mochi_1
from socaity.sdk.replicate.geobotsar81.geobotsar_flux_2 import geobotsar_flux_2
from socaity.sdk.replicate.google_deepmind.gemma_2b import gemma_2b
from socaity.sdk.replicate.google_deepmind.gemma_2b_it import gemma_2b_it
from socaity.sdk.replicate.google_deepmind.gemma_7b import gemma_7b
from socaity.sdk.replicate.google_deepmind.gemma_7b_it import gemma_7b_it
from socaity.sdk.replicate.hadilq.hair_segment import hair_segment
from socaity.sdk.replicate.halimalrasihi.flux_mystic_animals import flux_mystic_animals
from socaity.sdk.replicate.halimalrasihi.flux_red_cinema import flux_red_cinema
from socaity.sdk.replicate.haoheliu.audio_ldm import audio_ldm
from socaity.sdk.replicate.harmonai.dance_diffusion import dance_diffusion
from socaity.sdk.replicate.hartmamt.flux_chicago_firesidebowl import flux_chicago_firesidebowl
from socaity.sdk.replicate.hassamdevsy.mask2former import mask2former
from socaity.sdk.replicate.idea_research.ram_grounded_sam import ram_grounded_sam
from socaity.sdk.replicate.idvorkin.idvorkin_flux_lora_1 import idvorkin_flux_lora_1
from socaity.sdk.replicate.igorriti.flux_360 import flux_360
from socaity.sdk.replicate.igorriti.flux_fileteado import flux_fileteado
from socaity.sdk.replicate.ihor_thecoach.ihor2 import ihor2
from socaity.sdk.replicate.ismail_seleit.formfinder_flux import formfinder_flux
from socaity.sdk.replicate.jaaari.kokoro_82m import kokoro_82m
from socaity.sdk.replicate.jagilley.controlnet_canny import controlnet_canny
from socaity.sdk.replicate.jagilley.controlnet_depth2img import controlnet_depth2img
from socaity.sdk.replicate.jagilley.controlnet_hed import controlnet_hed
from socaity.sdk.replicate.jagilley.controlnet_hough import controlnet_hough
from socaity.sdk.replicate.jagilley.controlnet_normal import controlnet_normal
from socaity.sdk.replicate.jagilley.controlnet_pose import controlnet_pose
from socaity.sdk.replicate.jagilley.controlnet_scribble import controlnet_scribble
from socaity.sdk.replicate.jagilley.controlnet_seg import controlnet_seg
from socaity.sdk.replicate.jakedahn.flux_latentpop import flux_latentpop
from socaity.sdk.replicate.jakedahn.flux_soviet_controlrooms import flux_soviet_controlrooms
from socaity.sdk.replicate.jamorphy.moebius_flux_lora import moebius_flux_lora
from socaity.sdk.replicate.jan890.flux_dev_ascii_art import flux_dev_ascii_art
from socaity.sdk.replicate.janghaludu.kocchaga import kocchaga
from socaity.sdk.replicate.jarvis_labs2024.console_cowboy_flux import console_cowboy_flux
from socaity.sdk.replicate.jarvis_labs2024.flux_appleseed import flux_appleseed
from socaity.sdk.replicate.jarvis_labs2024.flux_raylene import flux_raylene
from socaity.sdk.replicate.jayenkai.derek import derek
from socaity.sdk.replicate.jbilcke.flux_dev_panorama_lora import flux_dev_panorama_lora
from socaity.sdk.replicate.jcbianchi010.jeancbianchi import jeancbianchi
from socaity.sdk.replicate.jd7h.edit_video_by_editing_text import edit_video_by_editing_text
from socaity.sdk.replicate.jd7h.zero123plusplus import zero123plusplus
from socaity.sdk.replicate.jfobrien29.flux_us_national_parks import flux_us_national_parks
from socaity.sdk.replicate.jiht76.mindyflux import mindyflux
from socaity.sdk.replicate.jingyunliang.hcflow_sr import hcflow_sr
from socaity.sdk.replicate.jingyunliang.swinir import swinir
from socaity.sdk.replicate.joshelgar.rssmurryflux import rssmurryflux
from socaity.sdk.replicate.juergengunz.ultimate_portrait_upscale import ultimate_portrait_upscale
from socaity.sdk.replicate.juliananev.frutiger_aero import frutiger_aero
from socaity.sdk.replicate.julienhypeer.julienetoke import julienetoke
from socaity.sdk.replicate.justmalhar.flux_mobile_ui import flux_mobile_ui
from socaity.sdk.replicate.justmalhar.flux_sketchnotes import flux_sketchnotes
from socaity.sdk.replicate.justmalhar.flux_thumbnails import flux_thumbnails
from socaity.sdk.replicate.jweek.mask_maker import mask_maker
from socaity.sdk.replicate.karlvann.karl import karl
from socaity.sdk.replicate.kazdatahelp.llkm import llkm
from socaity.sdk.replicate.kcaverly.nous_hermes_2_yi_34b_gguf import nous_hermes_2_yi_34b_gguf
from socaity.sdk.replicate.koratkar.miyazaki_watercolor import miyazaki_watercolor
from socaity.sdk.replicate.krthr.clip_embeddings import clip_embeddings
from socaity.sdk.replicate.levelsio.analog_film import analog_film
from socaity.sdk.replicate.levelsio.brain_flakes_ai import brain_flakes_ai
from socaity.sdk.replicate.levelsio.disposable_camera import disposable_camera
from socaity.sdk.replicate.levelsio.lomography import lomography
from socaity.sdk.replicate.levelsio.neon_tokyo import neon_tokyo
from socaity.sdk.replicate.lightricks.ltx_video import ltx_video
from socaity.sdk.replicate.linoytsaban.flux_yarn_art import flux_yarn_art
from socaity.sdk.replicate.lipex157zoi.lipexbradok import lipexbradok
from socaity.sdk.replicate.lisandroe.loralisandro import loralisandro
from socaity.sdk.replicate.lucataco.ace_step import ace_step
from socaity.sdk.replicate.lucataco.controlnet_tile import controlnet_tile
from socaity.sdk.replicate.lucataco.csm_1b import csm_1b
from socaity.sdk.replicate.lucataco.deep3d import deep3d
from socaity.sdk.replicate.lucataco.demofusion_enhance import demofusion_enhance
from socaity.sdk.replicate.lucataco.depth_anything_video import depth_anything_video
from socaity.sdk.replicate.lucataco.dreamshaper_xl_turbo import dreamshaper_xl_turbo
from socaity.sdk.replicate.lucataco.florence_2_large import florence_2_large
from socaity.sdk.replicate.lucataco.flux_queso import flux_queso
from socaity.sdk.replicate.lucataco.flux_syd_mead import flux_syd_mead
from socaity.sdk.replicate.lucataco.flux_vlta import flux_vlta
from socaity.sdk.replicate.lucataco.flux_watercolor import flux_watercolor
from socaity.sdk.replicate.lucataco.frame_extractor import frame_extractor
from socaity.sdk.replicate.lucataco.hotshot_xl import hotshot_xl
from socaity.sdk.replicate.lucataco.img_and_audio2video import img_and_audio2video
from socaity.sdk.replicate.lucataco.magnet import magnet
from socaity.sdk.replicate.lucataco.merge_img import merge_img
from socaity.sdk.replicate.lucataco.mvsep_mdx23_music_separation import mvsep_mdx23_music_separation
from socaity.sdk.replicate.lucataco.nomic_embed_text_v1 import nomic_embed_text_v1
from socaity.sdk.replicate.lucataco.nsfw_video_detection import nsfw_video_detection
from socaity.sdk.replicate.lucataco.open_dalle_v1_1 import open_dalle_v1_1
from socaity.sdk.replicate.lucataco.orpheus_3b_0_1_ft import orpheus_3b_0_1_ft
from socaity.sdk.replicate.lucataco.pasd_magnify import pasd_magnify
from socaity.sdk.replicate.lucataco.pheme import pheme
from socaity.sdk.replicate.lucataco.phi_2 import phi_2
from socaity.sdk.replicate.lucataco.phixtral_2x2_8 import phixtral_2x2_8
from socaity.sdk.replicate.lucataco.pixart_xl_2 import pixart_xl_2
from socaity.sdk.replicate.lucataco.qwen1_5_72b import qwen1_5_72b
from socaity.sdk.replicate.lucataco.qwen1_5_7b import qwen1_5_7b
from socaity.sdk.replicate.lucataco.real_esrgan_video import real_esrgan_video
from socaity.sdk.replicate.lucataco.realistic_vision_v5 import realistic_vision_v5
from socaity.sdk.replicate.lucataco.realistic_vision_v5_1 import realistic_vision_v5_1
from socaity.sdk.replicate.lucataco.realvisxl2_lcm import realvisxl2_lcm
from socaity.sdk.replicate.lucataco.realvisxl_v2_0 import realvisxl_v2_0
from socaity.sdk.replicate.lucataco.rembg_video import rembg_video
from socaity.sdk.replicate.lucataco.sdxl_controlnet import sdxl_controlnet
from socaity.sdk.replicate.lucataco.singing_voice_conversion import singing_voice_conversion
from socaity.sdk.replicate.lucataco.snowflake_arctic_embed_l import snowflake_arctic_embed_l
from socaity.sdk.replicate.lucataco.ssd_1b import ssd_1b
from socaity.sdk.replicate.lucataco.stable_diffusion_x4_upscaler import stable_diffusion_x4_upscaler
from socaity.sdk.replicate.lucataco.video_merge import video_merge
from socaity.sdk.replicate.lucataco.video_split import video_split
from socaity.sdk.replicate.lucataco.wan_2_1_1_3b_vid2vid import wan_2_1_1_3b_vid2vid
from socaity.sdk.replicate.lucataco.xtts_v2 import xtts_v2
from socaity.sdk.replicate.ludocomito.flux_caravaggio import flux_caravaggio
from socaity.sdk.replicate.m1guelpf.whisper_subtitles import whisper_subtitles
from socaity.sdk.replicate.makinsongary698.jh import jh
from socaity.sdk.replicate.mandelavybe.jungkook import jungkook
from socaity.sdk.replicate.marckohlbrugge.flux_wojak_v2 import flux_wojak_v2
from socaity.sdk.replicate.marcusschwarze.paul_mittelrheintaler import paul_mittelrheintaler
from socaity.sdk.replicate.mark3labs.embeddings_gte_base import embeddings_gte_base
from socaity.sdk.replicate.markbland82.mjbstyle1 import mjbstyle1
from socaity.sdk.replicate.markredito._90sbadtrip import _90sbadtrip
from socaity.sdk.replicate.maybasmanphotographer.bmayb import bmayb
from socaity.sdk.replicate.melaesse.ginevra import ginevra
from socaity.sdk.replicate.men1scus.birefnet import birefnet
from socaity.sdk.replicate.meta.llama_4_maverick_instruct import llama_4_maverick_instruct
from socaity.sdk.replicate.meta.meta_llama_3_1_405b_instruct import meta_llama_3_1_405b_instruct
from socaity.sdk.replicate.meta.meta_llama_3_70b_instruct import meta_llama_3_70b_instruct
from socaity.sdk.replicate.meta.meta_llama_3_8b import meta_llama_3_8b
from socaity.sdk.replicate.meta.meta_llama_3_8b_instruct import meta_llama_3_8b_instruct
from socaity.sdk.replicate.meta.musicgen import musicgen
from socaity.sdk.replicate.meta.sam_2 import sam_2
from socaity.sdk.replicate.meta.sam_2_video import sam_2_video
from socaity.sdk.replicate.midllle.material_maker import material_maker
from socaity.sdk.replicate.mintkaori.seoulgi import seoulgi
from socaity.sdk.replicate.mofleck.teslasemishipped import teslasemishipped
from socaity.sdk.replicate.mv_lab.swin2sr import swin2sr
from socaity.sdk.replicate.naklecha.clothing_segmentation import clothing_segmentation
from socaity.sdk.replicate.nateraw.audio_super_resolution import audio_super_resolution
from socaity.sdk.replicate.nateraw.autotune import autotune
from socaity.sdk.replicate.nateraw.bge_large_en_v1_5 import bge_large_en_v1_5
from socaity.sdk.replicate.nateraw.musicgen_songstarter_v0_2 import musicgen_songstarter_v0_2
from socaity.sdk.replicate.nateraw.nous_hermes_2_solar_10_7b import nous_hermes_2_solar_10_7b
from socaity.sdk.replicate.nateraw.nous_hermes_llama2_awq import nous_hermes_llama2_awq
from socaity.sdk.replicate.nateraw.stable_diffusion_videos import stable_diffusion_videos
from socaity.sdk.replicate.nicknaskida.whisper_diarization import whisper_diarization
from socaity.sdk.replicate.nicolas7894.flux_undraw import flux_undraw
from socaity.sdk.replicate.nicolascoutureau.video_utils import video_utils
from socaity.sdk.replicate.nightmareai.disco_diffusion import disco_diffusion
from socaity.sdk.replicate.nightmareai.latent_sr import latent_sr
from socaity.sdk.replicate.nightmareai.real_esrgan import real_esrgan
from socaity.sdk.replicate.nvidia.parakeet_rnnt_1_1b import parakeet_rnnt_1_1b
from socaity.sdk.replicate.nvidia.sana import sana
from socaity.sdk.replicate.nvidia.sana_sprint_1_6b import sana_sprint_1_6b
from socaity.sdk.replicate.okostadsjunior.ninicollyloli import ninicollyloli
from socaity.sdk.replicate.okturan.flux_yesilcam import flux_yesilcam
from socaity.sdk.replicate.open_mmlab.pia import pia
from socaity.sdk.replicate.openai.gpt_4_1 import gpt_4_1
from socaity.sdk.replicate.openai.gpt_4_1_mini import gpt_4_1_mini
from socaity.sdk.replicate.openai.gpt_4_1_nano import gpt_4_1_nano
from socaity.sdk.replicate.openai.gpt_4o import gpt_4o
from socaity.sdk.replicate.openai.gpt_4o_mini import gpt_4o_mini
from socaity.sdk.replicate.openai.o1 import o1
from socaity.sdk.replicate.openai.o1_mini import o1_mini
from socaity.sdk.replicate.openai.whisper import whisper
from socaity.sdk.replicate.ori299.mc_thumbnails_v1 import mc_thumbnails_v1
from socaity.sdk.replicate.oshtz.flux_celpast import flux_celpast
from socaity.sdk.replicate.oshtz.flux_plastic3d import flux_plastic3d
from socaity.sdk.replicate.paulbasic.flux_paulh import flux_paulh
from socaity.sdk.replicate.pbarker.gfpgan_video import gfpgan_video
from socaity.sdk.replicate.pbuyle.banchan_flux import banchan_flux
from socaity.sdk.replicate.pellmellism.xkcd import xkcd
from socaity.sdk.replicate.philz1337x.controlnet_deliberate import controlnet_deliberate
from socaity.sdk.replicate.platform_kit.mars5_tts import mars5_tts
from socaity.sdk.replicate.playgroundai.playground_v2_5_1024px_aesthetic import playground_v2_5_1024px_aesthetic
from socaity.sdk.replicate.pnyompen.sd_controlnet_lora import sd_controlnet_lora
from socaity.sdk.replicate.pollinations.modnet import modnet
from socaity.sdk.replicate.pollinations.real_basicvsr_video_superresolution import real_basicvsr_video_superresolution
from socaity.sdk.replicate.pollinations.stable_diffusion_dance import stable_diffusion_dance
from socaity.sdk.replicate.pollinations.tune_a_video import tune_a_video
from socaity.sdk.replicate.popovluka.luka_flux_lora_model import luka_flux_lora_model
from socaity.sdk.replicate.prestoncreed.flux_spongebob import flux_spongebob
from socaity.sdk.replicate.prunaai.flux_1_dev import flux_1_dev
from socaity.sdk.replicate.prunaai.hidream_l1_dev import hidream_l1_dev
from socaity.sdk.replicate.prunaai.hidream_l1_fast import hidream_l1_fast
from socaity.sdk.replicate.prunaai.hidream_l1_full import hidream_l1_full
from socaity.sdk.replicate.prunaai.hunyuan3d_2 import hunyuan3d_2
from socaity.sdk.replicate.prunaai.sdxl_lightning import sdxl_lightning
from socaity.sdk.replicate.prunaai.vace_14b import vace_14b
from socaity.sdk.replicate.prunaai.vace_1_3b import vace_1_3b
from socaity.sdk.replicate.pseudoram.rvc_v2 import rvc_v2
from socaity.sdk.replicate.pwntus.flux_albert_einstein import flux_albert_einstein
from socaity.sdk.replicate.qunash.circassian_culture_flux_3000_steps import circassian_culture_flux_3000_steps
from socaity.sdk.replicate.qunash.iphone_camera_style import iphone_camera_style
from socaity.sdk.replicate.rainer1966_de.flux_rainer import flux_rainer
from socaity.sdk.replicate.raulduke9119.flux_realism import flux_realism
from socaity.sdk.replicate.replicate.all_mpnet_base_v2 import all_mpnet_base_v2
from socaity.sdk.replicate.replicate.flan_t5_xl import flan_t5_xl
from socaity.sdk.replicate.replicate.gpt_j_6b import gpt_j_6b
from socaity.sdk.replicate.replicate.llama_7b import llama_7b
from socaity.sdk.replicate.replicate.train_rvc_model import train_rvc_model
from socaity.sdk.replicate.riffusion.riffusion import riffusion
from socaity.sdk.replicate.roberthein.modelname_new import modelname_new
from socaity.sdk.replicate.roelfrenkema.fatherofdragons import fatherofdragons
from socaity.sdk.replicate.roelfrenkema.flux1_lora_aurora import flux1_lora_aurora
from socaity.sdk.replicate.roelfrenkema.flux1_lora_betty import flux1_lora_betty
from socaity.sdk.replicate.roelfrenkema.flux1_lora_watercolors import flux1_lora_watercolors
from socaity.sdk.replicate.s76354m.fluxfinetune import fluxfinetune
from socaity.sdk.replicate.s_clementc.manon import manon
from socaity.sdk.replicate.sakemin.musicgen_stereo_chord import musicgen_stereo_chord
from socaity.sdk.replicate.schananas.grounded_sam import grounded_sam
from socaity.sdk.replicate.scmdr.ai_graphic import ai_graphic
from socaity.sdk.replicate.sczhou.codeformer import codeformer
from socaity.sdk.replicate.sdsgitaccount.flux_gmoveus import flux_gmoveus
from socaity.sdk.replicate.sebastianbodza.flux_aquarell_watercolor_style import flux_aquarell_watercolor_style
from socaity.sdk.replicate.sebastianbodza.flux_lora_retro_linedrawing_style_v1 import flux_lora_retro_linedrawing_style_v1
from socaity.sdk.replicate.sepal.audiogen import audiogen
from socaity.sdk.replicate.sevensevenimages.rolxsub import rolxsub
from socaity.sdk.replicate.shapestudio.floating_flux import floating_flux
from socaity.sdk.replicate.shapestudio.nihon_flux import nihon_flux
from socaity.sdk.replicate.shapestudio.portra_800_flux import portra_800_flux
from socaity.sdk.replicate.shapestudio.wild_flux import wild_flux
from socaity.sdk.replicate.sigil_wen.laika_flux_lora import laika_flux_lora
from socaity.sdk.replicate.sigil_wen.pepsi_flux import pepsi_flux
from socaity.sdk.replicate.smoretalk.rembg_enhance import rembg_enhance
from socaity.sdk.replicate.someone12dd.libreintense import libreintense
from socaity.sdk.replicate.someone12dd.muskoil1 import muskoil1
from socaity.sdk.replicate.stability_ai.sdxl import sdxl
from socaity.sdk.replicate.stability_ai.stable_diffusion import stable_diffusion
from socaity.sdk.replicate.stability_ai.stable_diffusion_inpainting import stable_diffusion_inpainting
from socaity.sdk.replicate.stability_ai.stablelm_tuned_alpha_7b import stablelm_tuned_alpha_7b
from socaity.sdk.replicate.stackadoc.stable_audio_open_1_0 import stable_audio_open_1_0
from socaity.sdk.replicate.suno_ai.bark import bark
from socaity.sdk.replicate.swook.inspyrenet import inspyrenet
from socaity.sdk.replicate.sylvesteraswin.sylvester_flux_selfie import sylvester_flux_selfie
from socaity.sdk.replicate.szdavid11.kellogs_chocos import kellogs_chocos
from socaity.sdk.replicate.szdavid11.ola_scooter import ola_scooter
from socaity.sdk.replicate.tahercoolguy.video_background_remover_appender import video_background_remover_appender
from socaity.sdk.replicate.tencent.hunyuan3d_2mv import hunyuan3d_2mv
from socaity.sdk.replicate.tencent.hunyuan_video import hunyuan_video
from socaity.sdk.replicate.tencentarc.animesr import animesr
from socaity.sdk.replicate.tencentarc.gfpgan import gfpgan
from socaity.sdk.replicate.tezzarida.aram import aram
from socaity.sdk.replicate.titouv.test_model3 import test_model3
from socaity.sdk.replicate.tjrndll.flux_dev_woodcut_prints import flux_dev_woodcut_prints
from socaity.sdk.replicate.tokaito14.art import art
from socaity.sdk.replicate.tokaito14.fullbody import fullbody
from socaity.sdk.replicate.tokaito14.laura import laura
from socaity.sdk.replicate.tokaito14.portrait import portrait
from socaity.sdk.replicate.tstramer.material_diffusion import material_diffusion
from socaity.sdk.replicate.tudortotolici.newspaper_illustration import newspaper_illustration
from socaity.sdk.replicate.tylerbishopdev.retylerv2 import retylerv2
from socaity.sdk.replicate.ugleh.flux_dev_lora_dixit import flux_dev_lora_dixit
from socaity.sdk.replicate.ugleh.flux_dev_lora_painterdetective import flux_dev_lora_painterdetective
from socaity.sdk.replicate.ummtushar.pilot import pilot
from socaity.sdk.replicate.urieltac.polar_fleece import polar_fleece
from socaity.sdk.replicate.usamaehsan.controlnet_1_1_x_realistic_vision_v2_0 import controlnet_1_1_x_realistic_vision_v2_0
from socaity.sdk.replicate.usamaehsan.controlnet_x_ip_adapter_realistic_vision_v5 import controlnet_x_ip_adapter_realistic_vision_v5
from socaity.sdk.replicate.vaibhavs10.incredibly_fast_whisper import incredibly_fast_whisper
from socaity.sdk.replicate.veryvanya.flux_ps1_style import flux_ps1_style
from socaity.sdk.replicate.warf23.agrat_me import agrat_me
from socaity.sdk.replicate.warf23.ai_glasses import ai_glasses
from socaity.sdk.replicate.witzelfitz.gardenflux import gardenflux
from socaity.sdk.replicate.wowohello.fat_funjin import fat_funjin
from socaity.sdk.replicate.x_lance.f5_tts import f5_tts
from socaity.sdk.replicate.xinntao.esrgan import esrgan
from socaity.sdk.replicate.yorickvp.llava_13b import llava_13b
from socaity.sdk.replicate.yorickvp.llava_v1_6_mistral_7b import llava_v1_6_mistral_7b
from socaity.sdk.replicate.yorickvp.llava_v1_6_vicuna_13b import llava_v1_6_vicuna_13b
from socaity.sdk.replicate.yoyo_nb.thin_plate_spline_motion_model import thin_plate_spline_motion_model
from socaity.sdk.replicate.yuezheng2006.flux_lora_gyy import flux_lora_gyy
from socaity.sdk.replicate.zeke.tarot_flux import tarot_flux
from socaity.sdk.replicate.zeke.ziki_flux import ziki_flux
from socaity.sdk.replicate.zsxkib.animate_diff import animate_diff
from socaity.sdk.replicate.zsxkib.animatediff_illusions import animatediff_illusions
from socaity.sdk.replicate.zsxkib.animatediff_prompt_travel import animatediff_prompt_travel
from socaity.sdk.replicate.zsxkib.aura_sr import aura_sr
from socaity.sdk.replicate.zsxkib.aura_sr_v2 import aura_sr_v2
from socaity.sdk.replicate.zsxkib.create_rvc_dataset import create_rvc_dataset
from socaity.sdk.replicate.zsxkib.diffbir import diffbir
from socaity.sdk.replicate.zsxkib.film_frame_interpolation_for_large_motion import film_frame_interpolation_for_large_motion
from socaity.sdk.replicate.zsxkib.flux_music import flux_music
from socaity.sdk.replicate.zsxkib.hunyuan_video2video import hunyuan_video2video
from socaity.sdk.replicate.zsxkib.ic_light_background import ic_light_background
from socaity.sdk.replicate.zsxkib.jina_clip_v2 import jina_clip_v2
from socaity.sdk.replicate.zsxkib.mimic_motion import mimic_motion
from socaity.sdk.replicate.zsxkib.mmaudio import mmaudio
from socaity.sdk.replicate.zsxkib.pyramid_flow import pyramid_flow
from socaity.sdk.replicate.zsxkib.realistic_voice_cloning import realistic_voice_cloning
from socaity.sdk.replicate.zsxkib.samurai import samurai
from socaity.sdk.replicate.zsxkib.stable_video_face_restoration import stable_video_face_restoration
from socaity.sdk.replicate.zsxkib.yolo_world import yolo_world
from socaity.sdk.replicate.zsyoaoa.invsr import invsr
from socaity.sdk.replicate.zylim0702.qr_code_controlnet import qr_code_controlnet
from socaity.sdk.replicate.zylim0702.remove_bg import remove_bg
from socaity.sdk.replicate.zzyjay.icedevsfm import icedevsfm