from socaity.sdk.replicate.jarvis_labs2024.console_cowboy_flux import console_cowboy_flux
from socaity.sdk.replicate.jarvis_labs2024.flux_appleseed import flux_appleseed
from socaity.sdk.replicate.jarvis_labs2024.flux_raylene import flux_raylene