from socaity.sdk.replicate.aramintak.enna_sketch_style import enna_sketch_style
from socaity.sdk.replicate.aramintak.flux_film_foto import flux_film_foto
from socaity.sdk.replicate.aramintak.flux_frosting_lane import flux_frosting_lane
from socaity.sdk.replicate.aramintak.flux_koda import flux_koda
from socaity.sdk.replicate.aramintak.flux_softserve_anime import flux_softserve_anime
from socaity.sdk.replicate.aramintak.linnea_flux_beta import linnea_flux_beta
from socaity.sdk.replicate.aramintak.mooniverse import mooniverse