from socaity.sdk.replicate.nightmareai.disco_diffusion import disco_diffusion
from socaity.sdk.replicate.nightmareai.latent_sr import latent_sr
from socaity.sdk.replicate.nightmareai.real_esrgan import real_esrgan