from socaity.sdk.replicate.datacte.flux_aesthetic_anime import flux_aesthetic_anime
from socaity.sdk.replicate.datacte.flux_synthetic_anime import flux_synthetic_anime
from socaity.sdk.replicate.datacte.proteus_v0_2 import proteus_v0_2
from socaity.sdk.replicate.datacte.proteus_v0_3 import proteus_v0_3