from socaity.sdk.replicate.fofr._0_1_webp import _0_1_webp
from socaity.sdk.replicate.fofr.any_comfyui_workflow import any_comfyui_workflow
from socaity.sdk.replicate.fofr.audio_to_waveform import audio_to_waveform
from socaity.sdk.replicate.fofr.aura_flow import aura_flow
from socaity.sdk.replicate.fofr.controlnet_preprocessors import controlnet_preprocessors
from socaity.sdk.replicate.fofr.flux_2004 import flux_2004
from socaity.sdk.replicate.fofr.flux_80s_cyberpunk import flux_80s_cyberpunk
from socaity.sdk.replicate.fofr.flux_bad_70s_food import flux_bad_70s_food
from socaity.sdk.replicate.fofr.flux_beyond_horizon import flux_beyond_horizon
from socaity.sdk.replicate.fofr.flux_black_light import flux_black_light
from socaity.sdk.replicate.fofr.flux_brighton_west_pier import flux_brighton_west_pier
from socaity.sdk.replicate.fofr.flux_cassette_futurism import flux_cassette_futurism
from socaity.sdk.replicate.fofr.flux_color import flux_color
from socaity.sdk.replicate.fofr.flux_cross_section import flux_cross_section
from socaity.sdk.replicate.fofr.flux_cyberpunk_typeface import flux_cyberpunk_typeface
from socaity.sdk.replicate.fofr.flux_hyundai_n_vision_74 import flux_hyundai_n_vision_74
from socaity.sdk.replicate.fofr.flux_jwst import flux_jwst
from socaity.sdk.replicate.fofr.flux_macro_texture import flux_macro_texture
from socaity.sdk.replicate.fofr.flux_minecraft_movie import flux_minecraft_movie
from socaity.sdk.replicate.fofr.flux_mjv3 import flux_mjv3
from socaity.sdk.replicate.fofr.flux_mona_lisa import flux_mona_lisa
from socaity.sdk.replicate.fofr.flux_myst import flux_myst
from socaity.sdk.replicate.fofr.flux_neo_1x import flux_neo_1x
from socaity.sdk.replicate.fofr.flux_pixar_cars import flux_pixar_cars
from socaity.sdk.replicate.fofr.flux_spitting_image import flux_spitting_image
from socaity.sdk.replicate.fofr.flux_tessellate import flux_tessellate
from socaity.sdk.replicate.fofr.flux_wrong import flux_wrong
from socaity.sdk.replicate.fofr.flux_y2k import flux_y2k
from socaity.sdk.replicate.fofr.frames_to_video import frames_to_video
from socaity.sdk.replicate.fofr.latent_consistency_model import latent_consistency_model
from socaity.sdk.replicate.fofr.musicgen_choral import musicgen_choral
from socaity.sdk.replicate.fofr.realvisxl_v3_multi_controlnet_lora import realvisxl_v3_multi_controlnet_lora
from socaity.sdk.replicate.fofr.sdxl_emoji import sdxl_emoji
from socaity.sdk.replicate.fofr.sdxl_multi_controlnet_lora import sdxl_multi_controlnet_lora
from socaity.sdk.replicate.fofr.sticker_maker import sticker_maker
from socaity.sdk.replicate.fofr.toolkit import toolkit
from socaity.sdk.replicate.fofr.tooncrafter import tooncrafter
from socaity.sdk.replicate.fofr.video_morpher import video_morpher
from socaity.sdk.replicate.fofr.video_to_frames import video_to_frames
from socaity.sdk.replicate.fofr.wan2_1_with_lora import wan2_1_with_lora