from socaity.sdk.replicate.jagilley.controlnet_canny import controlnet_canny
from socaity.sdk.replicate.jagilley.controlnet_depth2img import controlnet_depth2img
from socaity.sdk.replicate.jagilley.controlnet_hed import controlnet_hed
from socaity.sdk.replicate.jagilley.controlnet_hough import controlnet_hough
from socaity.sdk.replicate.jagilley.controlnet_normal import controlnet_normal
from socaity.sdk.replicate.jagilley.controlnet_pose import controlnet_pose
from socaity.sdk.replicate.jagilley.controlnet_scribble import controlnet_scribble
from socaity.sdk.replicate.jagilley.controlnet_seg import controlnet_seg