from socaity.sdk.replicate.levelsio.analog_film import analog_film
from socaity.sdk.replicate.levelsio.brain_flakes_ai import brain_flakes_ai
from socaity.sdk.replicate.levelsio.disposable_camera import disposable_camera
from socaity.sdk.replicate.levelsio.lomography import lomography
from socaity.sdk.replicate.levelsio.neon_tokyo import neon_tokyo