from socaity.sdk.replicate.andreasjansson.blip_2 import blip_2
from socaity.sdk.replicate.andreasjansson.cantable_diffuguesion import cantable_diffuguesion
from socaity.sdk.replicate.andreasjansson.clip_features import clip_features
from socaity.sdk.replicate.andreasjansson.flux_goo import flux_goo
from socaity.sdk.replicate.andreasjansson.flux_me import flux_me
from socaity.sdk.replicate.andreasjansson.flux_shapes import flux_shapes
from socaity.sdk.replicate.andreasjansson.illusion import illusion
from socaity.sdk.replicate.andreasjansson.llama_2_13b_embeddings import llama_2_13b_embeddings
from socaity.sdk.replicate.andreasjansson.music_inpainting_bert import music_inpainting_bert
from socaity.sdk.replicate.andreasjansson.musicgen_looper import musicgen_looper
from socaity.sdk.replicate.andreasjansson.stable_diffusion_animation import stable_diffusion_animation
from socaity.sdk.replicate.andreasjansson.tile_morph import tile_morph
from socaity.sdk.replicate.andreasjansson.wan_1_3b_inpaint import wan_1_3b_inpaint