from socaity.sdk.replicate.ai_forever.kandinsky_2 import kandinsky_2
from socaity.sdk.replicate.ai_forever.kandinsky_2_1 import kandinsky_2_1
from socaity.sdk.replicate.ai_forever.kandinsky_2_2 import kandinsky_2_2