from socaity.sdk.replicate.lucataco.ace_step import ace_step
from socaity.sdk.replicate.lucataco.controlnet_tile import controlnet_tile
from socaity.sdk.replicate.lucataco.csm_1b import csm_1b
from socaity.sdk.replicate.lucataco.deep3d import deep3d
from socaity.sdk.replicate.lucataco.demofusion_enhance import demofusion_enhance
from socaity.sdk.replicate.lucataco.depth_anything_video import depth_anything_video
from socaity.sdk.replicate.lucataco.dreamshaper_xl_turbo import dreamshaper_xl_turbo
from socaity.sdk.replicate.lucataco.florence_2_large import florence_2_large
from socaity.sdk.replicate.lucataco.flux_queso import flux_queso
from socaity.sdk.replicate.lucataco.flux_syd_mead import flux_syd_mead
from socaity.sdk.replicate.lucataco.flux_vlta import flux_vlta
from socaity.sdk.replicate.lucataco.flux_watercolor import flux_watercolor
from socaity.sdk.replicate.lucataco.frame_extractor import frame_extractor
from socaity.sdk.replicate.lucataco.hotshot_xl import hotshot_xl
from socaity.sdk.replicate.lucataco.img_and_audio2video import img_and_audio2video
from socaity.sdk.replicate.lucataco.magnet import magnet
from socaity.sdk.replicate.lucataco.merge_img import merge_img
from socaity.sdk.replicate.lucataco.mvsep_mdx23_music_separation import mvsep_mdx23_music_separation
from socaity.sdk.replicate.lucataco.nomic_embed_text_v1 import nomic_embed_text_v1
from socaity.sdk.replicate.lucataco.nsfw_video_detection import nsfw_video_detection
from socaity.sdk.replicate.lucataco.open_dalle_v1_1 import open_dalle_v1_1
from socaity.sdk.replicate.lucataco.orpheus_3b_0_1_ft import orpheus_3b_0_1_ft
from socaity.sdk.replicate.lucataco.pasd_magnify import pasd_magnify
from socaity.sdk.replicate.lucataco.pheme import pheme
from socaity.sdk.replicate.lucataco.phi_2 import phi_2
from socaity.sdk.replicate.lucataco.phixtral_2x2_8 import phixtral_2x2_8
from socaity.sdk.replicate.lucataco.pixart_xl_2 import pixart_xl_2
from socaity.sdk.replicate.lucataco.qwen1_5_72b import qwen1_5_72b
from socaity.sdk.replicate.lucataco.qwen1_5_7b import qwen1_5_7b
from socaity.sdk.replicate.lucataco.real_esrgan_video import real_esrgan_video
from socaity.sdk.replicate.lucataco.realistic_vision_v5 import realistic_vision_v5
from socaity.sdk.replicate.lucataco.realistic_vision_v5_1 import realistic_vision_v5_1
from socaity.sdk.replicate.lucataco.realvisxl2_lcm import realvisxl2_lcm
from socaity.sdk.replicate.lucataco.realvisxl_v2_0 import realvisxl_v2_0
from socaity.sdk.replicate.lucataco.rembg_video import rembg_video
from socaity.sdk.replicate.lucataco.sdxl_controlnet import sdxl_controlnet
from socaity.sdk.replicate.lucataco.singing_voice_conversion import singing_voice_conversion
from socaity.sdk.replicate.lucataco.snowflake_arctic_embed_l import snowflake_arctic_embed_l
from socaity.sdk.replicate.lucataco.ssd_1b import ssd_1b
from socaity.sdk.replicate.lucataco.stable_diffusion_x4_upscaler import stable_diffusion_x4_upscaler
from socaity.sdk.replicate.lucataco.video_merge import video_merge
from socaity.sdk.replicate.lucataco.video_split import video_split
from socaity.sdk.replicate.lucataco.wan_2_1_1_3b_vid2vid import wan_2_1_1_3b_vid2vid
from socaity.sdk.replicate.lucataco.xtts_v2 import xtts_v2