from socaity.sdk.replicate.adirik.e5_mistral_7b_instruct import e5_mistral_7b_instruct
from socaity.sdk.replicate.adirik.flux_cinestill import flux_cinestill
from socaity.sdk.replicate.adirik.flux_fantasy_architecture import flux_fantasy_architecture
from socaity.sdk.replicate.adirik.grounding_dino import grounding_dino
from socaity.sdk.replicate.adirik.imagedream import imagedream
from socaity.sdk.replicate.adirik.interior_design import interior_design
from socaity.sdk.replicate.adirik.mamba_130m import mamba_130m
from socaity.sdk.replicate.adirik.mamba_1_4b import mamba_1_4b
from socaity.sdk.replicate.adirik.mamba_2_8b import mamba_2_8b
from socaity.sdk.replicate.adirik.mamba_2_8b_slimpj import mamba_2_8b_slimpj
from socaity.sdk.replicate.adirik.mamba_370m import mamba_370m
from socaity.sdk.replicate.adirik.mamba_790m import mamba_790m
from socaity.sdk.replicate.adirik.mvdream import mvdream
from socaity.sdk.replicate.adirik.owlvit_base_patch32 import owlvit_base_patch32
from socaity.sdk.replicate.adirik.realvisxl_v3_0_turbo import realvisxl_v3_0_turbo
from socaity.sdk.replicate.adirik.realvisxl_v4_0 import realvisxl_v4_0
from socaity.sdk.replicate.adirik.styletts2 import styletts2
from socaity.sdk.replicate.adirik.text2tex import text2tex
from socaity.sdk.replicate.adirik.texture import texture
from socaity.sdk.replicate.adirik.wonder3d import wonder3d