from socaity.sdk.replicate.tencent.hunyuan3d_2mv import hunyuan3d_2mv
from socaity.sdk.replicate.tencent.hunyuan_video import hunyuan_video
from socaity.sdk.replicate.tencentarc.animesr import animesr
from socaity.sdk.replicate.tencentarc.gfpgan import gfpgan