from socaity.sdk.replicate.nateraw.audio_super_resolution import audio_super_resolution
from socaity.sdk.replicate.nateraw.autotune import autotune
from socaity.sdk.replicate.nateraw.bge_large_en_v1_5 import bge_large_en_v1_5
from socaity.sdk.replicate.nateraw.musicgen_songstarter_v0_2 import musicgen_songstarter_v0_2
from socaity.sdk.replicate.nateraw.nous_hermes_2_solar_10_7b import nous_hermes_2_solar_10_7b
from socaity.sdk.replicate.nateraw.nous_hermes_llama2_awq import nous_hermes_llama2_awq
from socaity.sdk.replicate.nateraw.stable_diffusion_videos import stable_diffusion_videos