from socaity.sdk.replicate.zsxkib.animate_diff import animate_diff
from socaity.sdk.replicate.zsxkib.animatediff_illusions import animatediff_illusions
from socaity.sdk.replicate.zsxkib.animatediff_prompt_travel import animatediff_prompt_travel
from socaity.sdk.replicate.zsxkib.aura_sr import aura_sr
from socaity.sdk.replicate.zsxkib.aura_sr_v2 import aura_sr_v2
from socaity.sdk.replicate.zsxkib.create_rvc_dataset import create_rvc_dataset
from socaity.sdk.replicate.zsxkib.diffbir import diffbir
from socaity.sdk.replicate.zsxkib.film_frame_interpolation_for_large_motion import film_frame_interpolation_for_large_motion
from socaity.sdk.replicate.zsxkib.flux_music import flux_music
from socaity.sdk.replicate.zsxkib.hunyuan_video2video import hunyuan_video2video
from socaity.sdk.replicate.zsxkib.ic_light_background import ic_light_background
from socaity.sdk.replicate.zsxkib.jina_clip_v2 import jina_clip_v2
from socaity.sdk.replicate.zsxkib.mimic_motion import mimic_motion
from socaity.sdk.replicate.zsxkib.mmaudio import mmaudio
from socaity.sdk.replicate.zsxkib.pyramid_flow import pyramid_flow
from socaity.sdk.replicate.zsxkib.realistic_voice_cloning import realistic_voice_cloning
from socaity.sdk.replicate.zsxkib.samurai import samurai
from socaity.sdk.replicate.zsxkib.stable_video_face_restoration import stable_video_face_restoration
from socaity.sdk.replicate.zsxkib.yolo_world import yolo_world