from socaity.sdk.replicate.shapestudio.floating_flux import floating_flux
from socaity.sdk.replicate.shapestudio.nihon_flux import nihon_flux
from socaity.sdk.replicate.shapestudio.portra_800_flux import portra_800_flux
from socaity.sdk.replicate.shapestudio.wild_flux import wild_flux