from socaity.sdk.replicate.cjwbw.controlvideo import controlvideo
from socaity.sdk.replicate.cjwbw.damo_text_to_video import damo_text_to_video
from socaity.sdk.replicate.cjwbw.parler_tts import parler_tts
from socaity.sdk.replicate.cjwbw.rembg import rembg
from socaity.sdk.replicate.cjwbw.rudalle_sr import rudalle_sr
from socaity.sdk.replicate.cjwbw.seamless_communication import seamless_communication
from socaity.sdk.replicate.cjwbw.semantic_segment_anything import semantic_segment_anything
from socaity.sdk.replicate.cjwbw.shap_e import shap_e
from socaity.sdk.replicate.cjwbw.supir import supir
from socaity.sdk.replicate.cjwbw.text2video_zero import text2video_zero
from socaity.sdk.replicate.cjwbw.videocrafter import videocrafter
from socaity.sdk.replicate.cjwbw.voicecraft import voicecraft